==> EmberFactory-1.1.3-py3-none-any.whl: emberweb/__init__.py <==
# -*- coding: utf-8 -*-
__version__ = '1.1.3'
"""
                 EmberFactory / web application

This script starts the Flask web app.
The user interface is managed by the 'control.py' module
The drawing code is in the 'embermaker' package.

Copyright (C) 2020  philippe.marbaix@uclouvain.be
"""
import os
from flask import Flask
from emberweb import control
from werkzeug.middleware.dispatcher import DispatcherMiddleware

# There are two version numbers: the main one below, and a specific version for the embermaker part;
# the idea is that if the main version changes, but not the embermaker part, there is no change in the procuced
# graphics at all (=> there are only changes related to user interface, documentation, etc.)
# The main version for the application:

def create_app(test_config=None):
    """Create and configure an instance of the Flask application."""
    app = Flask(__name__, instance_relative_config=True)

    # Default configuration
    # Maximum size of uploaded files (as security measure, see
    # https://stackoverflow.com/questions/31873989/rejecting-files-greater-than-a-certain-amount-with-flask-uploads )
    app.config['MAX_CONTENT_LENGTH'] = 2 * 1024 * 1024
    # A secret key is needed to store the user's preference about deleting his/her files in a cookie
    # You may change this in your emberfactory.cfg file (below), but afaik the only thing we are protecting here is
    # a choice made by the user, so I guess that it is not really important to have a hard-to-guess real 'secret' key.
    app.config["SECRET_KEY"] = "default-EF-key"

    # Read configuration from a file in the instance folder if it exists (silent = may fail)
    app.config.from_pyfile(os.path.join(app.instance_path, 'emberfactory.cfg'), silent=True)

    # By default, the root path for this app will be '/', this is practical to run it locally;
    # However, if you want to have a different root path, such as '/embermaker' just put it in the config
    # file read above, using the configuration parameter APPLICATION_ROOT.
    # Note that this is not the standard use of APPLICATION ROOT (it normally does not apply inside requests,
    # see https://flask.palletsprojects.com/en/1.1.x/config/ )
    app_root = app.config["APPLICATION_ROOT"]
    # The Dispatcher may combine several apps with different root path; here we have only one app,
    # so either the url starts with app_root and this app will process it, or it fails ('dummy_app').
    # https://flask.palletsprojects.com/en/1.1.x/patterns/appdispatch/#app-dispatch
    if app_root != '/':
        app.wsgi_app = DispatcherMiddleware(Flask('dummy_app'), {app_root: app.wsgi_app})

    # ensure the instance directory and subdirectories exists
    os.makedirs(app.instance_path, exist_ok=True)
    os.makedirs(os.path.join(app.instance_path, 'in/'),exist_ok=True)
    os.makedirs(os.path.join(app.instance_path, 'out/'),exist_ok=True)

    app.register_blueprint(control.bp)
    app.add_url_rule("/", endpoint="index")

    return app

==> EmberFactory-1.2.0-py3-none-any.whl: emberweb/__init__.py <==
# -*- coding: utf-8 -*-
__version__ = '1.2.0'
"""
                 EmberFactory / web application

This script starts the Flask web app.
The user interface is managed by the 'control.py' module
The drawing code is in the 'embermaker' package.

Copyright (C) 2020  philippe.marbaix@uclouvain.be
"""
import os
from flask import Flask
from emberweb import control, sitenav
from werkzeug.middleware.dispatcher import DispatcherMiddleware

# There are two version numbers: the main one below, and a specific version for the embermaker part;
# the idea is that if the main version changes, but not the embermaker part, there is no change in the procuced
# graphics at all (=> there are only changes related to user interface, documentation, etc.)
# The main version for the application:

def create_app(test_config=None):
    """Create and configure an instance of the Flask application."""
    app = Flask(__name__, instance_relative_config=True)

    # Default configuration
    # Maximum size of uploaded files (as security measure, see
    # https://stackoverflow.com/questions/31873989/rejecting-files-greater-than-a-certain-amount-with-flask-uploads )
    app.config['MAX_CONTENT_LENGTH'] = 2 * 1024 * 1024
    # A secret key is needed to store the user's preference about deleting his/her files in a cookie
    # You may change this in your emberfactory.cfg file (below), but afaik the only thing we are protecting here is
    # a choice made by the user, so I guess that it is not really important to have a hard-to-guess real 'secret' key.
    app.config["SECRET_KEY"] = "default-EF-key"
    app.config['SESSION_COOKIE_SAMESITE'] = "Strict"

    # Read configuration from a file in the instance folder if it exists (silent = may fail)
    app.config.from_pyfile(os.path.join(app.instance_path, 'emberfactory.cfg'), silent=True)

    # By default, the root path for this app will be '/', this is practical to run it locally;
    # However, if you want to have a different root path, such as '/embermaker' just put it in the config
    # file read above, using the configuration parameter APPLICATION_ROOT.
    # Note that this is not the standard use of APPLICATION ROOT (it normally does not apply inside requests,
    # see https://flask.palletsprojects.com/en/1.1.x/config/ )
    app_root = app.config["APPLICATION_ROOT"]
    # The Dispatcher may combine several apps with different root path; here we have only one app,
    # so either the url starts with app_root and this app will process it, or it fails ('dummy_app').
    # https://flask.palletsprojects.com/en/1.1.x/patterns/appdispatch/#app-dispatch
    if app_root != '/':
        app.wsgi_app = DispatcherMiddleware(Flask('dummy_app'), {app_root: app.wsgi_app})

    # ensure the instance directory and subdirectories exists
    os.makedirs(app.instance_path, exist_ok=True)
    os.makedirs(os.path.join(app.instance_path, 'in/'),exist_ok=True)
    os.makedirs(os.path.join(app.instance_path, 'out/'),exist_ok=True)

    app.register_blueprint(control.bp)
    app.register_blueprint(sitenav.bp)

    app.add_url_rule("/", endpoint="index")

    return app
